%global _gnu %{nil}
%global _program_prefix eu-


Summary: Utilities and DSOs to handle ELF files and DWARF data
Name: elfutils
Version: 0.190
Release: 2%{?dist}
License: GPLv3+ and (GPLv2+ or LGPLv3+) and GFDL
URL: http://elfutils.org/
Source0: https://sourceware.org/elfutils/ftp/%{version}/%{name}-%{version}.tar.bz2

# https://sourceware.org/bugzilla/show_bug.cgi?id=31058
patch0001: cve-2024-25260.patch

BuildRequires: gcc gcc-c++
BuildRequires: automake autoconf gettext-devel
BuildRequires: gettext bison flex zstd
BuildRequires: zlib-devel bzip2-devel
BuildRequires: xz-devel libzstd-devel
BuildRequires: pkgconfig(libmicrohttpd) >= 0.9.33
BuildRequires: pkgconfig(libcurl) >= 7.29.0
BuildRequires: pkgconfig(sqlite3) >= 3.7.17
BuildRequires: pkgconfig(libarchive) >= 3.1.2
# For bunzip2 test files.
BuildRequires: bzip2
BuildRequires: procps curl bsdtar

Requires: elfutils-libelf = %{version}-%{release}
Requires: elfutils-libs = %{version}-%{release}


%description
This package provides elfutils, a collection of utilities, including stack (to show
backtraces), nm (to list symbols from object files), size
(to list the section sizes of an object or archive file),
strip (to discard symbols), readelf (to see the raw ELF file
structures), elflint (to check for well-formed ELF files) and
elfcompress (to compress or decompress ELF sections).


%package libs
Summary: Elfutils libraries to handle compiled objects
License: GPLv2+ or LGPLv3+
Requires: elfutils-libelf = %{version}-%{release}
Requires: default-yama-scope

%description libs
This package provides libraries which implement DWARF, ELF,
and machine-specific ELF handling and process introspection. These
libraries are used by the programs in the elfutils package, 
which can be used for building other programs using these
libraries.


%package devel
Summary: Elfutils development libraries to handle compiled objects
License: GPLv2+ or LGPLv3+
Requires: elfutils-libs = %{version}-%{release}
Requires: elfutils-libelf-devel = %{version}-%{release}


%description devel
This package provides libraries to create
applications for handling compiled objects. libdw is used to get
the DWARF debugging information. libasm provides a programmable
assembler interface.


%package libelf
Summary: Library to read and write ELF files
License: GPLv2+ or LGPLv3+


%description libelf
This package provides a DSO which allows reading and
writing ELF files on a high level. Third party programs depend on
this package to read internals of ELF files. The programs in the
elfutils package use it also to generate new ELF files.


%package libelf-devel
Summary: Development support for libelf
License: GPLv2+ or LGPLv3+
Requires: elfutils-libelf = %{version}-%{release}


%description libelf-devel
This package contains the libraries to create
applications for handling compiled objects. libelf allows users to
access the internals of the ELF object file format, so users can see the
different sections of an ELF file.


%package default-yama-scope
Summary: Default yama attach scope sysctl setting
License: GPLv2+ or LGPLv3+
BuildArch: noarch
BuildRequires: systemd >= 215
Recommends: systemd
Provides: default-yama-scope

%description default-yama-scope
Yama sysctl setting to enable default attach scope settings
enabling programs to use ptrace attach, access to
/proc/PID/{mem,personality,stack,syscall}, and the syscalls
process_vm_readv and process_vm_writev which are used for
interprocess services, communication and introspection
(like synchronisation, signaling, debugging, tracing and
profiling) of processes.
Install this package to control kernel.yama.ptrace_scope.



%prep
%autosetup -p1
autoreconf -fiv
# make sure all testcase executable
find . -name *.sh ! -perm -0100 -print | xargs chmod +x

%build
%configure CFLAGS="$RPM_OPT_FLAGS -Wformat -Wno-error" --disable-debuginfod
%make_build

%install
%make_install

chmod +x %{buildroot}%{_libdir}/lib*.so*
# remove static lib
rm %{buildroot}%{_libdir}/lib{elf,dw,asm}.a

# remove all the debuginfod stuff, no package on debuginfod
rm -f %{buildroot}/%{_sysconfdir}/profile.d/debuginfod.*sh
rm -f %{buildroot}/%{_libdir}/pkgconfig/libdebuginfod.pc
rm -f %{buildroot}/%{_bindir}/debuginfod-find
rm -f %{buildroot}/%{_includedir}/elfutils/debuginfod.h
rm -f %{buildroot}/%{_libdir}/libdebuginfod*
rm -f %{buildroot}/%{_mandir}/man1/debuginfod*
rm -f %{buildroot}/%{_mandir}/man3/debuginfod*
rm -f %{buildroot}/%{_mandir}/man7/debuginfod*

%find_lang %{name}

install -D -m 0644 config/10-default-yama-scope.conf %{buildroot}%{_sysctldir}/10-default-yama-scope.conf

%check
%make_build check || (cat tests/test-suite.log; false)

%post default-yama-scope
# due to circular dependencies, check existance of systemd-sysctl
# systemd > elfutils-libs > default-yama-scope > systemd
if [ -x /usr/lib/systemd/systemd-sysctl ] ; then
    %sysctl_apply 10-default-yama-scope.conf
fi


%files
%license COPYING COPYING-GPLV2 COPYING-LGPLV3 doc/COPYING-GFDL
%doc README TODO CONTRIBUTING
%{_bindir}/eu-addr2line
%{_bindir}/eu-ar
%{_bindir}/eu-elfclassify
%{_bindir}/eu-elfcmp
%{_bindir}/eu-elfcompress
%{_bindir}/eu-elflint
%{_bindir}/eu-findtextrel
%{_bindir}/eu-make-debug-archive
%{_bindir}/eu-nm
%{_bindir}/eu-objdump
%{_bindir}/eu-ranlib
%{_bindir}/eu-readelf
%{_bindir}/eu-size
%{_bindir}/eu-stack
%{_bindir}/eu-strings
%{_bindir}/eu-strip
%{_bindir}/eu-unstrip
%{_bindir}/eu-srcfiles
%{_mandir}/man1/eu-*.1*

%files libs
%license COPYING-GPLV2 COPYING-LGPLV3
%{_libdir}/libdw.so.*
%{_libdir}/libasm.so.*
%{_libdir}/libdw-%{version}.so
%{_libdir}/libasm-%{version}.so

%files devel
%{_includedir}/dwarf.h
%dir %{_includedir}/elfutils
%{_includedir}/elfutils/elf-knowledge.h
%{_includedir}/elfutils/known-dwarf.h
%{_includedir}/elfutils/libasm.h
%{_includedir}/elfutils/libdw.h
%{_includedir}/elfutils/libdwfl.h
%{_includedir}/elfutils/libdwelf.h
%{_includedir}/elfutils/version.h
%{_libdir}/libdw.so
%{_libdir}/libasm.so
%{_libdir}/pkgconfig/libdw.pc

%files -f %{name}.lang libelf
%license COPYING-GPLV2 COPYING-LGPLV3
%{_libdir}/libelf.so.*
%{_libdir}/libelf-%{version}.so

%files libelf-devel
%{_includedir}/libelf.h
%{_includedir}/gelf.h
%{_includedir}/nlist.h
%{_libdir}/libelf.so
%{_libdir}/pkgconfig/libelf.pc
%{_mandir}/man3/elf_*.3*


%files default-yama-scope
%{_sysctldir}/10-default-yama-scope.conf


%changelog
* Tue Feb 27 2024 rockerzhu <rockerzhu@tencent.com> - 0.190-2
- Fix cve-2024-25260

* Thu Jan 11 2024 rockerzhu <rockerzhu@tencent.com> - 0.190-1
- Upgrade to 0.190

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.189-2
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Jul 07 2023 kianli <kianli@tencent.com> - 0.189-1
- Upgrade to 0.189

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.187-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.187-2
- Rebuilt for OpenCloudOS Stream 23

* Tue Jul 05 2022 Yi Lin <nilusyi@tencent.com> - 0.187-1
- package init.
